@@ -2,6 +2,8 @@ constexpr auto contributors = ""
 "Albrecht Dress, "
 "Christian Eichler, "
 "Digia Plc and/or its subsidiaries, "
+"Florian Pigorsch, "
+"Gunnar Skjold, "
 "Henri Hornburg, "
 "Ivo Kronenberg, "
 "Joerg Wunsch, "
