@@ -21,19 +21,17 @@
 
 #include "device/IDevice.h"
 
-class CDeviceTwoNav : public IDevice
-{
-public:
-    CDeviceTwoNav(const QString& path, const QString& key, const QString& model, QTreeWidget* parent);
-    virtual ~CDeviceTwoNav();
+class CDeviceTwoNav : public IDevice {
+ public:
+  CDeviceTwoNav(const QString& path, const QString& key, const QString& model, QTreeWidget* parent);
+  virtual ~CDeviceTwoNav();
 
-    void insertCopyOfProject(IGisProject* project) override;
+  void insertCopyOfProject(IGisProject* project) override;
 
-private:
-    void readReginfo(const QString& filename);
+ private:
+  void readReginfo(const QString& filename);
 
-    QString pathData;
+  QString pathData;
 };
 
-#endif //CDEVICETWONAV_H
-
+#endif  // CDEVICETWONAV_H
