@@ -21,15 +21,14 @@
 
 #include "gis/fit/decoder/IFitDecoderState.h"
 
-class CFitCrcState final : public IFitDecoderState
-{
-    Q_DECLARE_TR_FUNCTIONS(CFitCrcState)
-public:
-    CFitCrcState(shared_state_data_t& data) : IFitDecoderState(data) { reset(); }
-    virtual ~CFitCrcState() {}
+class CFitCrcState final : public IFitDecoderState {
+  Q_DECLARE_TR_FUNCTIONS(CFitCrcState)
+ public:
+  CFitCrcState(shared_state_data_t& data) : IFitDecoderState(data) { reset(); }
+  virtual ~CFitCrcState() {}
 
-    void reset() override;
-    decode_state_e process(quint8& dataByte) override;
+  void reset() override;
+  decode_state_e process(quint8& dataByte) override;
 };
 
-#endif //CFITCRCSTATE_H
+#endif  // CFITCRCSTATE_H
