@@ -21,21 +21,20 @@
 
 #include "gis/fit/decoder/IFitDecoderState.h"
 
-class CFitFieldDefinitionState final : public IFitDecoderState
-{
-public:
-    CFitFieldDefinitionState(shared_state_data_t& data) : IFitDecoderState(data) { reset(); }
-    virtual ~CFitFieldDefinitionState() {}
+class CFitFieldDefinitionState final : public IFitDecoderState {
+ public:
+  CFitFieldDefinitionState(shared_state_data_t& data) : IFitDecoderState(data) { reset(); }
+  virtual ~CFitFieldDefinitionState() {}
 
-    void reset() override;
-    decode_state_e process(quint8& dataByte) override;
+  void reset() override;
+  decode_state_e process(quint8& dataByte) override;
 
-private:
-    quint8 offset;
+ private:
+  quint8 offset;
 
-    quint8 defNr;
-    quint8 type;
-    quint8 size;
+  quint8 defNr;
+  quint8 type;
+  quint8 size;
 };
 
-#endif //CFITFIELDDEFINITIONSTATE_H
+#endif  // CFITFIELDDEFINITIONSTATE_H
