@@ -19,29 +19,28 @@
 #ifndef CPOSITIONDIALOG_H
 #define CPOSITIONDIALOG_H
 
-#include "ui_IPositionDialog.h"
 #include <QDialog>
 
+#include "ui_IPositionDialog.h"
+
 class QPointF;
 
-class CPositionDialog : public QDialog, private Ui::IPositionDialog
-{
-    Q_OBJECT
-public:
-    CPositionDialog(QWidget* parent, QPointF& pos);
-    virtual ~CPositionDialog();
+class CPositionDialog : public QDialog, private Ui::IPositionDialog {
+  Q_OBJECT
+ public:
+  CPositionDialog(QWidget* parent, QPointF& pos);
+  virtual ~CPositionDialog();
 
-    static bool getPosition(QPointF& pt, const QString& str);
+  static bool getPosition(QPointF& pt, const QString& str);
 
-public slots:
-    void accept() override;
+ public slots:
+  void accept() override;
 
-private slots:
-    void slotEdit(const QString& str);
+ private slots:
+  void slotEdit(const QString& str);
 
-private:
-    QPointF& pos;
+ private:
+  QPointF& pos;
 };
 
-#endif //CPOSITIONDIALOG_H
-
+#endif  // CPOSITIONDIALOG_H
