@@ -49,8 +49,7 @@ CMapTMS::CMapTMS(const QString& filename, CMapDraw* parent) : IMapOnline(parent)
   qDebug() << "TMS: try to open" << filename;
 
   proj.init(
-      "+proj=merc +a=6378137 +b=6378137 +lat_ts=0.0 +lon_0=0.0 +x_0=0.0 +y_0=0 +k=1.0 +units=m +nadgrids=@null +wktext "
-      "+no_defs",
+      "EPSG:3857",
       "EPSG:4326");
 
   qDebug() << "tms:" << proj.getProjSrc();
@@ -151,21 +150,22 @@ CMapTMS::CMapTMS(const QString& filename, CMapDraw* parent) : IMapOnline(parent)
 
 void CMapTMS::getLayers(QListWidget& list) /* override */
 {
-  QMutexLocker lock(&mutex);
-
-  list.clear();
-  if (layers.size() < 2) {
+  if (!mutex.tryLock(100)) {
     return;
   }
 
-  int i = 0;
-  for (const layer_t& layer : qAsConst(layers)) {
-    QListWidgetItem* item = new QListWidgetItem(layer.title, &list);
-    item->setCheckState(layer.enabled ? Qt::Checked : Qt::Unchecked);
-    item->setData(Qt::UserRole, i++);
-  }
+  list.clear();
+  if (layers.size() > 1) {
+    int i = 0;
+    for (const layer_t& layer : qAsConst(layers)) {
+      QListWidgetItem* item = new QListWidgetItem(layer.title, &list);
+      item->setCheckState(layer.enabled ? Qt::Checked : Qt::Unchecked);
+      item->setData(Qt::UserRole, i++);
+    }
 
-  connect(&list, &QListWidget::itemChanged, this, &CMapTMS::slotLayersChanged);
+    connect(&list, &QListWidget::itemChanged, this, &CMapTMS::slotLayersChanged);
+  }
+  mutex.unlock();
 }
 
 void CMapTMS::saveConfig(QSettings& cfg) /* override */
