@@ -19,13 +19,8 @@
 
 #include "CMouseDummy.h"
 
-CMouseDummy::CMouseDummy()
-    : IMouse(nullptr, nullptr, nullptr)
-{
-    cursor = QCursor(QPixmap(":/cursors/cursorArrow.png"), 0, 0);
-}
-
-CMouseDummy::~CMouseDummy()
-{
+CMouseDummy::CMouseDummy() : IMouse(nullptr, nullptr, nullptr) {
+  cursor = QCursor(QPixmap(":/cursors/cursorArrow.png"), 0, 0);
 }
 
+CMouseDummy::~CMouseDummy() {}
