@@ -30,59 +30,42 @@ class IMouse;
 
 #define SCR_OPT_OFFSET 15
 
-class IScrOpt : public QWidget
-{
-public:
-    IScrOpt(IMouse* mouse);
-    virtual ~IScrOpt();
+class IScrOpt : public QWidget {
+ public:
+  IScrOpt(IMouse* mouse);
+  virtual ~IScrOpt();
 
-    void setOrigin(const QPoint& pos)
-    {
-        origin = pos;
-    }
+  void setOrigin(const QPoint& pos) { origin = pos; }
 
-    const QPoint& getOrigin() const
-    {
-        return origin;
-    }
+  const QPoint& getOrigin() const { return origin; }
 
-    virtual void draw(QPainter& p) = 0;
-    virtual void mouseMove(const QPoint& pos);
+  virtual void draw(QPainter& p) = 0;
+  virtual void mouseMove(const QPoint& pos);
 
-    bool isNotLocked() const
-    {
-        return semaphore.available();
-    }
+  bool isNotLocked() const { return semaphore.available(); }
 
-protected slots:
-    void slotLinkActivated(const QString& link);
+ protected slots:
+  void slotLinkActivated(const QString& link);
 
-protected:
-    void enterEvent(QEvent* e) override;
-    void leaveEvent(QEvent* e) override;
-    // block mouse actions to hit the canvas
-    void mousePressEvent(QMouseEvent* e) override
-    {
-        e->accept();
-    }
-    // block mouse actions to hit the canvas
-    void mouseMoveEvent(QMouseEvent* e) override
-    {
-        e->accept();
-    }
+ protected:
+  void enterEvent(QEvent* e) override;
+  void leaveEvent(QEvent* e) override;
+  // block mouse actions to hit the canvas
+  void mousePressEvent(QMouseEvent* e) override { e->accept(); }
+  // block mouse actions to hit the canvas
+  void mouseMoveEvent(QMouseEvent* e) override { e->accept(); }
 
-    void moveTo(const QPoint& anchor);
+  void moveTo(const QPoint& anchor);
 
-    QPoint origin;
-    QPoint mousePos;
+  QPoint origin;
+  QPoint mousePos;
 
-    QPointer<IMouse> mouse;
+  QPointer<IMouse> mouse;
 
-    friend class CScrOptSemaphoreLocker;
-    QSemaphore semaphore {1};
+  friend class CScrOptSemaphoreLocker;
+  QSemaphore semaphore{1};
 
-    QColor backgroundColor;
+  QColor backgroundColor;
 };
 
-#endif //ISCROPT_H
-
+#endif  // ISCROPT_H
