@@ -24,24 +24,17 @@
 
 #include <QStringList>
 
-class CAppOpts
-{
-public:
-    const bool debug;            // -d, print debug messages
-    const bool logfile;          // -f, print debug messages to logfile
-    const bool nosplash;         // -n, do not display splash screen
-    const QString configfile;
-    const QStringList arguments;
+class CAppOpts {
+ public:
+  const bool debug;     // -d, print debug messages
+  const bool logfile;   // -f, print debug messages to logfile
+  const bool nosplash;  // -n, do not display splash screen
+  const QString configfile;
+  const QStringList arguments;
 
-    CAppOpts(bool doDebug, bool doLogfile, bool noSplash, const QString& config, const QStringList& args)
-        : debug(doDebug)
-        , logfile(doLogfile)
-        , nosplash(noSplash)
-        , configfile(config)
-        , arguments(args)
-    {
-    }
+  CAppOpts(bool doDebug, bool doLogfile, bool noSplash, const QString& config, const QStringList& args)
+      : debug(doDebug), logfile(doLogfile), nosplash(noSplash), configfile(config), arguments(args) {}
 };
 
 extern CAppOpts* qlOpts;
-#endif                           //CAPPOPTS_H
+#endif  // CAPPOPTS_H
